import type { LoginResult, ProfileDetail, ProfileParams } from '@/types/member'
import { defineStore } from 'pinia'
import { ref } from 'vue'

// 定义 Store
export const useMemberStore = defineStore(
  'member',
  () => {
    // 会员信息
    const profile = ref<LoginResult>()

    // 保存会员信息，登录时使用
    const setProfile = (val: LoginResult) => {
      profile.value = val
    }

    // 清理会员信息，退出时使用
    const clearProfile = () => {
      profile.value = undefined
    }

    // 更新头像
    const updateAvatar = (avatar: string) => {
      if (profile.value) {
        profile.value.avatar = avatar
      }
    }

    // 更新个人信息
    const updateProfile = (
      val: Pick<ProfileDetail, 'nickname' | 'gender' | 'birthday' | 'profession'>,
    ) => {
      console.log('调用action updateProfile', val)
      if (profile.value) {
        Object.assign(profile.value, val)
      }
    }

    // 记得 return
    return {
      profile,
      setProfile,
      clearProfile,
      updateAvatar,
      updateProfile,
    }
  },
  {
    // 网页端配置
    // persist: true,
    // 小程序端配置
    persist: {
      storage: {
        getItem(key) {
          return uni.getStorageSync(key)
        },
        setItem(key, value) {
          uni.setStorageSync(key, value)
        },
      },
    },
  },
)
